@@ -30,18 +30,19 @@ import tarfile
 import tempfile
 import unicodedata
 import zipfile
-from contextlib import closing, contextmanager
+from contextlib import contextmanager
 from typing import List, Optional, Union
 from xml.etree import ElementTree as ET
 
 import toml
 from setuptools.command.egg_info import translate_pattern
 
+
 # import distutils after setuptools to avoid a warning
-from distutils.text_file import TextFile
+from distutils.text_file import TextFile  # isort:skip
 
 
-__version__ = '0.45'
+__version__ = '0.46'
 __author__ = 'Marius Gedminas <marius@gedmin.as>'
 __licence__ = 'MIT'
 __url__ = 'https://github.com/mgedmin/check-manifest'
@@ -155,7 +156,7 @@ def run(
                                 stdout=subprocess.PIPE,
                                 stderr=subprocess.PIPE, cwd=cwd)
     except OSError as e:
-        raise Failure("could not run %s: %s" % (command, e))
+        raise Failure(f"could not run {command}: {e}")
     output, stderr = pipe.communicate()
     status = pipe.wait()
     if status != 0:
@@ -314,10 +315,10 @@ def get_archive_file_list(archive_filename):
     Supports .tar.gz and .zip.
     """
     if archive_filename.endswith('.zip'):
-        with closing(zipfile.ZipFile(archive_filename)) as zf:
+        with zipfile.ZipFile(archive_filename) as zf:
             filelist = zf.namelist()
     elif archive_filename.endswith(('.tar.gz', '.tar.bz2', '.tar')):
-        with closing(tarfile.open(archive_filename)) as tf:
+        with tarfile.open(archive_filename) as tf:
             # XXX: is unicodify() necessary now that Py2 is no longer supported?
             filelist = map(unicodify, tf.getnames())
     else:
